$.jqplot.AxisLabelRenderer

Renderer to place labels on the axes.

Summary

$.jqplot.AxisLabelRenderer | Renderer to place labels on the axes.
Properties |
show | whether or not to show the tick (mark and label).
label | The text or html for the label.
escapeHTML | true to escape HTML entities in the label.

### Properties

### show

> this.show = true

whether or not to show the tick (mark and label).

### label

> this.label = ''

The text or html for the label.

### escapeHTML

> this.escapeHTML = false

true to escape HTML entities in the label.

> this.show = true

whether or not to show the tick (mark and label).

> this.label = ''

The text or html for the label.

> this.escapeHTML = false

true to escape HTML entities in the label.
Close